@@ -82,8 +82,15 @@ maxCUDASharesPerContainer = {{max_cuda_shares_per_container}}
 maxShmPerContainer = {{max_shm_per_container}}
 maxFileUploadSize = {{max_file_upload_size}}
 
+[environments]
+{% if environment_allowlist %}
+allowlist = "{{environment_allowlist}}"
+{% endif %}
+
 [menu]
+{% if menu_blocklist %}
 blocklist = "{{menu_blocklist}}"
+{% endif %}
 
 {% if console_menu_plugins %}
 [plugin]
@@ -195,6 +202,7 @@ async def console_handler(request: web.Request) -> web.StreamResponse:
             'max_cuda_shares_per_container': max_cuda_shares_per_container,
             'max_shm_per_container': max_shm_per_container,
             'max_file_upload_size': max_file_upload_size,
+            'environment_allowlist': config['environments'].get('allowlist', ''),
             'menu_blocklist': config['ui'].get('menu_blocklist', ''),
             'console_menu_plugins': console_menu_plugins,
             'license_edition': license_edition,
@@ -441,7 +449,10 @@ async def token_login_handler(request: web.Request) -> web.Response:
         assert anon_api_config.is_anonymous
         async with APISession(config=anon_api_config) as api_session:
             # Send X-Forwarded-For header for token authentication with the client IP.
-            _headers = {'X-Forwarded-For': request.headers.get('X-Forwarded-For', '')}
+            client_ip = request.headers.get('X-Forwarded-For')
+            if not client_ip:
+                client_ip = request.remote
+            _headers = {'X-Forwarded-For': client_ip}
             api_session.aiohttp_session.headers.update(_headers)
             # Instead of email and password, cookie token will be used for auth.
             api_session.aiohttp_session.cookie_jar.update_cookies(request.cookies)
